#!/usr/bin/env perl

use warnings;
use strict;

use Getopt::Long;

my %opt = (evtfile => 'acis_evt2.fits',
	   outroot => 'thumbnail',
	   size_sky => 1000,	# Size of thumb in pixels
	   size_img => 400,     # Approx size of output image (pixels)
	   bin      => 1,       # Binning of pixels
	  );

GetOptions(\%opt,
	   'evtfile=s',
	   'x=f',
	   'y=f',
	   'detsize=f',
	   'regionfile=s',
	   'outjpg=s',
	   'outfits=s',
	   'size_sky=f',
	   'size_img=f',
	   'bin=f',
	   'autoscale=f',
	  );

my $x = $opt{x};
my $y = $opt{y};
my $detsize = $opt{detsize};
my $size_sky = defined $opt{autoscale} ? ($opt{autoscale} * $detsize)
  : $opt{size_sky};
my $x0 = sprintf("%.1f", $x-$size_sky/2);
my $x1 = sprintf("%.1f", $x+$size_sky/2);
my $y0 = sprintf("%.1f", $y-$size_sky/2);
my $y1 = sprintf("%.1f", $y+$size_sky/2);
my $bin_img = sprintf("%.6f", $size_sky / $opt{size_img});
my $dmregrid = <<DMREGRID ;
dmregrid \\
 infile='$opt{evtfile}\[bin x=$x0:$x1:$opt{bin},y=$y0:$y1:$opt{bin}]' \\
 outfile='$opt{outfits}' \\
 bin="$x0:$x1:$bin_img,$y0:$y1:$bin_img" \\
 coord_sys=physical \\
 rotangle=0 rotxcenter=0 rotycenter=0 \\
 xoffset=0 yoffset=0 \\
 npts=0 \\
 clobber=yes \\
 verbose=0
DMREGRID

my $dmimg2jpg = <<DMIMG2JPG ;
 dmimg2jpg \\
  infile=$opt{outfits} \\
  greenfile=none \\
  bluefile=none \\
  outfile=$opt{outjpg} \\
  showaimpoint=no \\
  showgrid=no \\
  scalefunction=log \\
  invert=yes \\
  regionfile='$opt{regionfile}' \\
  clobber=yes 
DMIMG2JPG


print $dmregrid . "\n";
system($dmregrid) and die "Problem running command";
    
print $dmimg2jpg . "\n";
system($dmimg2jpg) and die "Problem running command";
    
